@@ -290,12 +290,14 @@ get_xaproperty (Window win, Atom prop, Atom type, int *nitems)
     unsigned long items_ret;
     unsigned long after_ret;
     unsigned char *prop_data;
-
+    int i;
+    
     ENTER;
     prop_data = NULL;
-    XGetWindowProperty (GDK_DISPLAY(), win, prop, 0, 0x7fffffff, False,
-          type, &type_ret, &format_ret, &items_ret,
-          &after_ret, &prop_data);    
+    if (XGetWindowProperty (GDK_DISPLAY(), win, prop, 0, 0x7fffffff, False,
+              type, &type_ret, &format_ret, &items_ret,
+              &after_ret, &prop_data) != Success)
+        RET(NULL);
     if (nitems)
         *nitems = items_ret;
     RET(prop_data);
@@ -750,5 +752,24 @@ get_button_spacing(GtkRequisition *req, GtkContainer *parent, gchar *name)
 }
 
     
+guint32 gcolor2rgb24(GdkColor *color)
+{
+    guint32 i;
+    guint16 r, g, b;
+    
+    ENTER;
 
+    r = color->red * 0xFF / 0xFFFF;
+    g = color->green * 0xFF / 0xFFFF;
+    b = color->blue * 0xFF / 0xFFFF;
+    DBG("%x %x %x ==> %x %x %x\n", color->red, color->green, color->blue, r, g, b);
+    
+    i = (color->red * 0xFF / 0xFFFF) & 0xFF;
+    i <<= 8;
+    i |= (color->green * 0xFF / 0xFFFF) & 0xFF;
+    i <<= 8;
+    i |= (color->blue * 0xFF / 0xFFFF) & 0xFF;
+    DBG("i=%x\n", i);
+    RET(i);
+}
 
