@@ -19,19 +19,19 @@
 
 static gchar *cfgfile = NULL;
 static gchar version[] = VERSION;
-static gchar *cprofile = "default";
+gchar *cprofile = "default";
 
 int verbose;
+int config = 0;
 FbEv *fbev;
 
 //#define DEBUG
 #include "dbg.h"
 
 
+FILE *pconf; // plugin part of profile file
 
-
-static FILE *pfp; /* current profile FP */
-static panel *p;
+panel *p;
 
 
 /****************************************************
@@ -103,6 +103,7 @@ print_wmdata(panel *p)
     int i;
 
     ENTER;
+    RET();
     DBG("desktop %d/%d\n", p->curdesk, p->desknum);
     DBG("workarea\n");
     for (i = 0; i < p->wa_len/4; i++)
@@ -182,14 +183,20 @@ panel_destroy_event(GtkWidget * widget, GdkEvent * event, gpointer data)
 {
     //panel *p = (panel *) data;
 
-    ENTER;  
+    ENTER2;  
     //if (!p->self_destroy)
     gtk_main_quit();
     RET(FALSE);
 }
 
 
+static void
+panel_realize(GtkWidget *widget, panel *p)
+{
+    ENTER;
+    RET();
 
+}
 static gint
 panel_size_req(GtkWidget *widget, GtkRequisition *req, panel *p)
 {
@@ -209,15 +216,18 @@ panel_size_req(GtkWidget *widget, GtkRequisition *req, panel *p)
 static gint
 panel_size_alloc(GtkWidget *widget, GtkAllocation *a, panel *p)
 {
+    GtkAllocation *aa = &widget->allocation;
+    
     ENTER;
-    DBG("new alloc: size (%d, %d). pos (%d, %d)\n", a->width, a->height, a->x, a->y);
-    DBG("old alloc: size (%d, %d). pos (%d, %d)\n", p->aw, p->ah, p->ax, p->ay);
+    DBG("installed alloc: size (%d, %d). pos (%d, %d)\n", aa->width, aa->height, aa->x, aa->y);
+    DBG("suggested alloc: size (%d, %d). pos (%d, %d)\n", a->width, a->height, a->x, a->y);
+    DBG("prev pref alloc: size (%d, %d). pos (%d, %d)\n", p->aw, p->ah, p->ax, p->ay);
     if (p->widthtype == WIDTH_REQUEST)
         p->width = (p->orientation == ORIENT_HORIZ) ? a->width : a->height;
     if (p->heighttype == HEIGHT_REQUEST)
         p->height = (p->orientation == ORIENT_HORIZ) ? a->height : a->width;
     calculate_position(p);
-    DBG("pref alloc: size (%d, %d). pos (%d, %d)\n", p->aw, p->ah, p->ax, p->ay);
+    DBG("curr pref alloc: size (%d, %d). pos (%d, %d)\n", p->aw, p->ah, p->ax, p->ay);
     if (a->width == p->aw && a->height == p->ah && a->x == p->ax && a->y == p ->ay) {
         DBG("actual coords eq to preffered. just returning\n");
         RET(TRUE);
@@ -233,6 +243,9 @@ panel_size_alloc(GtkWidget *widget, GtkAllocation *a, panel *p)
         }
     */
     gtk_window_move(GTK_WINDOW(p->topgwin), p->ax, p->ay);
+    //gdk_window_move_resize (p->topgwin->window, p->ax, p->ay, p->aw, p->ah);
+    DBG("moving to %d %d\n", p->ax, p->ay);
+    //gdk_flush();
     if (p->setstrut)
         panel_set_wm_strut(p);
     //gdk_window_clear(p->topgwin->window);
@@ -240,6 +253,24 @@ panel_size_alloc(GtkWidget *widget, GtkAllocation *a, panel *p)
 }
 
 
+static  gboolean
+panel_configure_event (GtkWidget *widget, GdkEventConfigure *e, panel *p)
+{
+    ENTER;
+    if (e->width == p->cw && e->height == p->ch && e->x == p->cx && e->y == p->cy)
+        RET(TRUE);
+    p->cw = e->width;
+    p->ch = e->height;
+    p->cx = e->x;
+    p->cy = e->y;
+    DBG("here\n");
+    if (p->transparent)
+        fb_bg_notify_changed_bg(p->bg);
+    DBG("here\n");
+    DBG("geom: size (%d, %d). pos (%d, %d)\n", e->width, e->height, e->x, e->y);
+    RET(FALSE);
+    
+}
 
 
 /****************************************************
@@ -306,6 +337,9 @@ panel_start_gui(panel *p)
     gtk_window_set_resizable(GTK_WINDOW(p->topgwin), FALSE);
     gtk_window_set_wmclass(GTK_WINDOW(p->topgwin), "panel", "fbpanel");
     gtk_window_set_title(GTK_WINDOW(p->topgwin), "panel");
+    gtk_window_set_position(GTK_WINDOW(p->topgwin), GTK_WIN_POS_NONE);
+    gtk_window_set_decorated(GTK_WINDOW(p->topgwin), FALSE);
+    
     g_signal_connect(G_OBJECT(p->topgwin), "delete-event",
           G_CALLBACK(panel_delete_event), p);
     g_signal_connect(G_OBJECT(p->topgwin), "destroy-event",
@@ -314,10 +348,15 @@ panel_start_gui(panel *p)
           (GCallback) panel_size_req, p);
     g_signal_connect (G_OBJECT (p->topgwin), "size-allocate",
           (GCallback) panel_size_alloc, p);
+    g_signal_connect (G_OBJECT (p->topgwin), "configure-event",
+          (GCallback) panel_configure_event, p);
+    g_signal_connect (G_OBJECT (p->topgwin), "realize",
+          (GCallback) panel_realize, p);
+     
     gtk_widget_realize(p->topgwin);
-    gdk_window_set_decorations(p->topgwin->window, 0);
+    //gdk_window_set_decorations(p->topgwin->window, 0);
     gtk_widget_set_app_paintable(p->topgwin, TRUE);
-
+    
     // background box all over toplevel
     p->bbox = gtk_bgbox_new();
     gtk_container_add(GTK_CONTAINER(p->topgwin), p->bbox);
@@ -337,12 +376,12 @@ panel_start_gui(panel *p)
         make_round_corners(p);
  
     p->box = p->my_box_new(FALSE, 1); 
-    gtk_container_set_border_width(GTK_CONTAINER(p->box), 1);
+    gtk_container_set_border_width(GTK_CONTAINER(p->box), 0);
     gtk_box_pack_start(GTK_BOX(p->lbox), p->box, TRUE, TRUE, 0);
     gtk_widget_show(p->box);
       
     p->topxwin = GDK_WINDOW_XWINDOW(GTK_WIDGET(p->topgwin)->window);
-    
+    DBG("topxwin = %x\n", p->topxwin);
 
     /* the settings that should be done before window is mapped */
     wmhints.flags = InputHint;
@@ -422,8 +461,13 @@ panel_parse_global(panel *p, FILE *fp)
                 p->transparent = str2num(bool_pair, s.t[1], 0);
             } else if (!g_ascii_strcasecmp(s.t[0], "Alpha")) {
                 p->alpha = atoi(s.t[1]);
+                if (p->alpha > 255)
+                    p->alpha = 255;
             } else if (!g_ascii_strcasecmp(s.t[0], "TintColor")) {
-                p->tintcolor = strtoul(s.t[1], NULL, 0);
+                if (!gdk_color_parse (s.t[1], &p->gtintcolor))
+                    gdk_color_parse ("white", &p->gtintcolor);
+                p->tintcolor = gcolor2rgb24(&p->gtintcolor);
+                DBG("tintcolor=%x\n", p->tintcolor);
             } else {
                 ERR( "fbpanel: %s - unknown var in Global section\n", s.t[0]);
                 RET(0);
@@ -554,7 +598,8 @@ int
 panel_start(panel *p, FILE *fp)
 {
     line s;
-
+    long pos;
+    
     /* parse global section */
     ENTER;
     s.len = 256;
@@ -579,8 +624,15 @@ panel_start(panel *p, FILE *fp)
     if (!panel_parse_global(p, fp))
         RET(0);
 
+    if (!(pconf = tmpfile())) {
+        ERR("can't open temporary file\n");
+        RET(0);
+    }
+    pos = ftell(fp);
+    while (get_line_as_is(fp, &s) != LINE_NONE) 
+        fprintf(pconf, "%s\n", s.str);
+    fseek(fp, pos, SEEK_SET);
 
- 
     while (get_line(fp, &s) != LINE_NONE) {
         if ((s.type  != LINE_BLOCK_START) || g_ascii_strcasecmp(s.t[0], "Plugin")) {
             ERR( "fbpanel: expecting Plugin section\n");
@@ -611,11 +663,16 @@ void panel_stop(panel *p)
     g_list_foreach(p->plugins, delete_plugin, NULL);
     g_list_free(p->plugins);
     p->plugins = NULL;
-    g_object_unref(fbev);
+ 
     XSelectInput (GDK_DISPLAY(), GDK_ROOT_WINDOW(), NoEventMask);
     gdk_window_remove_filter(gdk_get_default_root_window (), (GdkFilterFunc)panel_event_filter, p);
     gtk_widget_destroy(p->topgwin);
+    g_object_unref(fbev);
     g_free(p->workarea);
+    fclose(pconf);
+    gdk_flush();
+    XFlush(GDK_DISPLAY());
+    XSync(GDK_DISPLAY(), True);
     RET();
 }
 
@@ -626,12 +683,17 @@ usage()
     ENTER;
     printf("fbpanel %s - lightweight GTK2+ panel for UNIX desktops\n", version);
     printf("Command line options:\n");
-    printf(" -h  -- print this help and exit\n");
-    printf(" -v  -- print version and exit\n");
-    printf(" -verbose  -- print usefull messages at runtime\n");
-    printf(" -p <name> -- use named profile. File ~/.fbpanel/<name> must exist\n");
-    printf("\nVisit http://fbpanel.sourceforge.net/ for detailed documentation,\n");
-    printf("sample profiles and other stuff.\n\n");
+    printf(" --help      -- print this help and exit\n");
+    printf(" --version   -- print version and exit\n");
+    printf(" --verbose   -- print usefull messages at runtime\n");
+    printf(" --configure -- launch configuration utility\n");
+    printf(" --profile name -- use specified profile\n");
+    printf("\n");
+    printf(" -h  -- same as --help\n");
+    printf(" -p  -- same as --profile\n");
+    printf(" -v  -- same as --version\n");
+    printf(" -C  -- same as --configure\n");
+    printf("\nVisit http://fbpanel.sourceforge.net/ for detailed documentation,\n\n");
 }
 
 FILE *
@@ -691,7 +753,9 @@ main(int argc, char *argv[], char *env[])
 {
     int i;
     int quit = 0;
-
+    void configure();
+    FILE *pfp; /* current profile FP */
+    
     ENTER;
     setlocale(LC_CTYPE, "");
     gtk_set_locale();
@@ -700,15 +764,17 @@ main(int argc, char *argv[], char *env[])
     XSetErrorHandler((XErrorHandler) handle_error);
     resolve_atoms();
     for (i = 1; i < argc; i++) {
-        if (!strcmp(argv[i], "-h")) {
+        if (!strcmp(argv[i], "-h") || !strcmp(argv[i], "--help")) {
             usage();
             exit(0);
-        } else if (!strcmp(argv[i], "-v")) {
+        } else if (!strcmp(argv[i], "-v") || !strcmp(argv[i], "--version")) {
             printf("fbpanel %s\n", version);
             exit(0);
-        } else if (!strcmp(argv[i], "-verbose")) {
+        } else if (!strcmp(argv[i], "--verbose")) {
             verbose = 1;
-        } else if (!strcmp(argv[i], "-p")) {
+        } else if (!strcmp(argv[i], "--configure") || !strcmp(argv[i], "-C")) {
+            config = 1;
+        } else if (!strcmp(argv[i], "--profile") || !strcmp(argv[i], "-p")) {
             i++;
             if (i == argc) {
                 ERR( "fbpanel: missing profile name\n");
@@ -725,6 +791,8 @@ main(int argc, char *argv[], char *env[])
     }
     signal(SIGUSR1, sig_usr);
     do {
+        if (verbose)
+            ERR("starting panel\n");
         if (!(pfp = open_profile(cprofile)))
             exit(1);
         p = g_new0(panel, 1);
@@ -734,6 +802,8 @@ main(int argc, char *argv[], char *env[])
             exit(1);
         }
         fclose(pfp);
+        if (config)
+            configure();
         gtk_main();
         panel_stop(p);
         g_free(p);
