@@ -120,7 +120,6 @@ plugin_load(char *type)
 #ifndef STATIC_PLUGINS
     if (!tmp && g_module_supported()) {
         GModule *m;
-        gpointer p;
 
         DBG("loading dll %s\n", type);
         if (!str)
@@ -135,7 +134,7 @@ plugin_load(char *type)
             DBG("opening %s\n", str->str);
         }
         if (!m) {
-            DBG("%s\n", g_module_error());
+            ERR("%s\n", g_module_error());
             RET(NULL);
         }
         if (verbose)
@@ -187,6 +186,7 @@ plugin_start(plugin *this)
 
     if (!this->class->invisible) {
         this->pwid = gtk_bgbox_new();
+        gtk_widget_set_name(this->pwid, this->class->type);
         gtk_box_pack_start(GTK_BOX(this->panel->box), this->pwid, this->expand, TRUE,
               this->padding);
         if (this->panel->transparent) 
@@ -205,6 +205,7 @@ plugin_start(plugin *this)
 void plugin_stop(plugin *this)
 {
     ENTER;
+    DBG("%s\n", this->class->type);
     this->class->destructor(this);
     this->panel->plug_num--;
     if (!this->class->invisible) 
