@@ -65,7 +65,7 @@ struct _desk {
 };
 
 struct _pager {
-    GtkWidget *box;
+    GtkWidget *box, *eb;
     desk *desks[MAX_DESK_NUM];
     guint desknum;
     guint curdesk;
@@ -194,6 +194,7 @@ desk_button_press_event(GtkWidget * widget, GdkEventButton * event, desk *d)
     RET(TRUE);
 }
 
+/*
 static gint
 desk_button_release_event(GtkWidget * widget, GdkEventButton * event, desk *d)
 {
@@ -202,6 +203,7 @@ desk_button_release_event(GtkWidget * widget, GdkEventButton * event, desk *d)
     Xclimsg(GDK_ROOT_WINDOW(), a_NET_CURRENT_DESKTOP, d->no, 0, 0, 0, 0);
     RET(TRUE);
 }
+*/
 
 static gint
 desk_scroll_event (GtkWidget *widget, GdkEventScroll *event, desk *d)
@@ -316,10 +318,13 @@ get_sizepos(task *t)
     XWindowAttributes win_attributes;
     
     ENTER;
-    if (!XGetWindowAttributes(GDK_DISPLAY(), t->win, &win_attributes))
-        XGetGeometry (GDK_DISPLAY(), t->win, &root, &t->x, &t->y, &t->w, &t->h,
-              &dummy, &dummy);
-    else {
+    if (!XGetWindowAttributes(GDK_DISPLAY(), t->win, &win_attributes)) {
+        if (!XGetGeometry (GDK_DISPLAY(), t->win, &root, &t->x, &t->y, &t->w, &t->h,
+                  &dummy, &dummy)) {
+            t->x = t->y = t->w = t->h = 2;
+        }
+            
+    } else {
         XTranslateCoordinates (GDK_DISPLAY(), t->win, win_attributes.root, 
               -win_attributes.border_width,
               -win_attributes.border_width,
@@ -410,7 +415,8 @@ do_net_client_list_stacking(FbEv *ev, pager *p)
             get_net_wm_state(t->win, &t->nws);
             get_net_wm_window_type(t->win, &t->nwwt);
             get_sizepos(t);
-            XSelectInput (GDK_DISPLAY(), t->win, PropertyChangeMask | StructureNotifyMask);
+            if (!gdk_window_lookup(t->win))
+                XSelectInput (GDK_DISPLAY(), t->win, PropertyChangeMask | StructureNotifyMask);
             g_hash_table_insert(p->htable, &t->win, t);
             DBG("add %x\n", t->win);
             desk_set_dirty(p, t);
@@ -632,12 +638,17 @@ pager_constructor(plugin *p)
     p->priv = pg;
 
     pg->htable = g_hash_table_new (g_int_hash, g_int_equal);
+    // pager is wrapped into eventbox to ensure non-transparent bg
+    pg->eb = gtk_event_box_new();
+    gtk_container_set_border_width (GTK_CONTAINER (pg->eb), 0);
+    gtk_widget_show(pg->eb);
     pg->box = p->panel->my_box_new(TRUE, 1);
-    gtk_container_set_border_width (GTK_CONTAINER (pg->box), 0);
+    gtk_container_set_border_width (GTK_CONTAINER (pg->box), 1);
     gtk_widget_show(pg->box);
     g_signal_connect (G_OBJECT (pg->box), "map",
           (GCallback) pager_map_event, (gpointer)pg);
-    gtk_container_add(GTK_CONTAINER(p->pwid), pg->box);
+    gtk_container_add(GTK_CONTAINER(pg->eb), pg->box);
+    gtk_container_add(GTK_CONTAINER(p->pwid), pg->eb);
     if (p->panel->orientation == ORIENT_HORIZ) {
         pg->dh = p->panel->ah - 2;
         pg->dw = (float)pg->dh * (float)gdk_screen_width() / (float) gdk_screen_height();
@@ -683,7 +694,7 @@ pager_destructor(plugin *p)
     }
     g_hash_table_foreach_remove(pg->htable, (GHRFunc) remove_all_tasks, (gpointer)pg);
     g_hash_table_destroy(pg->htable);
-    gtk_widget_destroy(pg->box);
+    gtk_widget_destroy(pg->eb);
     g_free(pg);
     RET();
 }
