@@ -146,7 +146,8 @@ get_wmclass(task *tk)
         XFree(tk->ch.res_name);
     if (tk->ch.res_class)
         XFree(tk->ch.res_class);
-    XGetClassHint (gdk_display, tk->win, &tk->ch);
+    if (!XGetClassHint (gdk_display, tk->win, &tk->ch)) 
+        tk->ch.res_class = tk->ch.res_name = NULL;
     RET();
 }
 
@@ -157,8 +158,11 @@ inline static void
 tk_free_names(task *tk)
 {    
     ENTER;
+    DBG("tk->name %s\n", tk->name);
+    DBG("tk->iname %s\n", tk->iname);
     g_free(tk->name);
     g_free(tk->iname);
+
     tk->name = tk->iname = NULL;
     RET();
 }
@@ -171,7 +175,7 @@ tk_set_names(task *tk)
     ENTER;
     tk_free_names(tk);
     name = get_textproperty(tk->win,  XA_WM_NAME);
-    DBG("utf name: <%s>\n", name);
+    DBG("utf name: %s\n", name);
     if (name) {		
 	tk->name = g_strdup_printf(" %s ", name);
 	tk->iname = g_strdup_printf("[%s]", name);
@@ -197,6 +201,8 @@ find_task (taskbar * tb, Window win)
 static void
 del_task (taskbar * tb, task *tk, int hdel)
 {
+    ENTER;
+    DBG("deleting(%d)  %08x %s\n", hdel, tk->win, tk->name);
     gtk_widget_destroy(tk->eb);
     tb->num_tasks--; 
     tk_free_names(tk);	    
@@ -205,6 +211,7 @@ del_task (taskbar * tb, task *tk, int hdel)
     if (hdel)
         g_hash_table_remove(tb->task_list, &tk->win);
     g_free(tk);
+    RET();
 }
 
 
@@ -346,7 +353,9 @@ apply_mask (GdkPixbuf *pixbuf,
 static void
 free_pixels (guchar *pixels, gpointer data)
 {
-  g_free (pixels);
+    ENTER;
+    g_free (pixels);
+    RET();
 }
 
 
@@ -627,8 +636,10 @@ tk_update(gpointer key, task *tk, taskbar *tb)
         //_gtk_button_set_depressed(GTK_BUTTON(tk->button), tk->focused);
 	gtk_widget_show(tk->eb);
 
-        if (tb->tooltips)
+        if (tb->tooltips) {
+            //DBG2("tip %x %s\n", tk->win, tk->name);
             gtk_tooltips_set_tip(tb->tips, tk->button, tk->name, NULL);
+        }
 	RET();
     }    
     gtk_widget_hide(tk->eb);
@@ -661,10 +672,14 @@ tk_build_gui(taskbar *tb, task *tk)
     ENTER;
     g_assert ((tb != NULL) && (tk != NULL));
 
-    //XSelectInput (GDK_DISPLAY(), tk->win, PropertyChangeMask);
-    /* the extended mask is sum of taskbar and pager needs
-     * see bug [ 940441 ] pager loose track of windows */
-    XSelectInput (GDK_DISPLAY(), tk->win, PropertyChangeMask | StructureNotifyMask);
+    /* NOTE
+     * 1. the extended mask is sum of taskbar and pager needs
+     * see bug [ 940441 ] pager loose track of windows 
+     *
+     * Do not change event mask to gtk windows spwaned by this gtk client
+     * this breaks gtk internals */
+    if (!gdk_window_lookup(tk->win))
+        XSelectInput (GDK_DISPLAY(), tk->win, PropertyChangeMask | StructureNotifyMask);
 
     /* button */
     tk->eb = gtk_event_box_new();
@@ -687,7 +702,7 @@ tk_build_gui(taskbar *tb, task *tk)
     gtk_container_set_border_width(GTK_CONTAINER(w1), 0);
 
     /* pix */
-    get_wmclass(tk);
+    //get_wmclass(tk);
     tk_update_icon(tb, tk, None);
     tk->image = gtk_image_new_from_pixbuf(tk->pixbuf );
     gtk_widget_show(tk->image);
@@ -719,6 +734,7 @@ tk_build_gui(taskbar *tb, task *tk)
 static gboolean
 tb_remove_stale_tasks(Window *win, task *tk, gpointer data)
 {
+    ENTER;
     if (tk->refcount-- == 0) {
         //DBG("tb_net_list <del>: 0x%x %s\n", tk->win, tk->name);
         del_task(tk->tb, tk, 0);
@@ -773,6 +789,7 @@ tb_net_client_list(GtkWidget *widget, taskbar *tb)
             tk_build_gui(tb, tk);
             tk_set_names(tk);
             g_hash_table_insert(tb->task_list, &tk->win, tk);
+            DBG("adding %08x(%p) %s\n", tk->win, gdk_window_lookup(tk->win), tk->name);
         }
     }
     
@@ -788,16 +805,20 @@ tb_net_client_list(GtkWidget *widget, taskbar *tb)
 static void
 tb_net_current_desktop(GtkWidget *widget, taskbar *tb)
 {
+    ENTER;
     tb->cur_desk = get_net_current_desktop();
     tb_display(tb);
+    RET();
 }
 
 
 static void
 tb_net_number_of_desktops(GtkWidget *widget, taskbar *tb)
 {
+    ENTER;
     tb->desk_num = get_net_number_of_desktops();
     tb_display(tb);
+    RET();
 }
 
 
@@ -866,16 +887,21 @@ tb_propertynotify(taskbar *tb, XEvent *ev)
 	task *tk = find_task(tb, win);
         
 	if (!tk) RET();
+        DBG("win=%x\n", ev->xproperty.window);
 	if (at == a_NET_WM_DESKTOP) {
+            DBG("NET_WM_DESKTOP\n");
 	    tk->desktop = get_net_wm_desktop(win);
 	    tb_display(tb);	
 	}  else if (at == XA_WM_NAME) {
+            DBG("WM_NAME\n");
 	    tk_set_names(tk);
 	    //tk_display(tb, tk);
 	}  else if (at == XA_WM_CLASS) {
-	    get_wmclass(tk);
+            DBG("WM_CLASS\n");
 
+            //get_wmclass(tk);
 	} else if (at == a_WM_STATE)    {
+            DBG("WM_STATE\n");
 	    /* iconified state changed? */
 	    tk->iconified = (get_wm_state (tk->win) == IconicState);
             tk_set_names(tk);
@@ -883,7 +909,7 @@ tb_propertynotify(taskbar *tb, XEvent *ev)
 	} else if (at == XA_WM_HINTS)	{
 	    /* some windows set their WM_HINTS icon after mapping */
 	    DBG("XA_WM_HINTS\n");
-            get_wmclass(tk);
+            //get_wmclass(tk);
             DBG("#0 %d\n", GDK_IS_PIXBUF (tk->pixbuf));
 	    tk_update_icon (tb, tk, XA_WM_HINTS);
             DBG("#1 %d\n", GDK_IS_PIXBUF (tk->pixbuf));
@@ -892,6 +918,7 @@ tb_propertynotify(taskbar *tb, XEvent *ev)
       	    //tk_display(tb, tk);
 	} else if (at == a_NET_WM_STATE) {
             net_wm_state nws;
+
 	    DBG("_NET_WM_STATE\n");
 	    get_net_wm_state(tk->win, &nws);
             if (!accept_net_wm_state(&nws, tb->accept_skip_pager)) {
@@ -907,14 +934,16 @@ tb_propertynotify(taskbar *tb, XEvent *ev)
             DBG("#2 %d\n", GDK_IS_PIXBUF (tk->pixbuf));
 	} else if (at == a_NET_WM_WINDOW_TYPE) {
             net_wm_window_type nwwt;
+
 	    DBG("_NET_WM_WINDOW_TYPE\n");
 	    get_net_wm_window_type(tk->win, &nwwt);
             if (!accept_net_wm_window_type(&nwwt)) {
 		del_task(tb, tk, 1);
 		tb_display(tb);
 	    }
+	} else {
+            DBG("at = %d\n", at);
 	}
-	
     }
     RET();
 }
@@ -1015,7 +1044,7 @@ taskbar_build_gui(plugin *p)
     gtk_box_pack_start(GTK_BOX(tb->hbox), tb->bbox, TRUE, TRUE, 0);
     */
     bo = (tb->plug->panel->orientation == ORIENT_HORIZ) ? GTK_BAR_HORIZ : GTK_BAR_VERTICAL;
-    tb->bar = gtk_bar_new(bo, 3); 
+    tb->bar = gtk_bar_new(bo, 0); 
     if (tb->icons_only) {
         gtk_bar_set_max_child_size(GTK_BAR(tb->bar),
               GTK_WIDGET(p->panel->box)->allocation.height -2);        
@@ -1026,7 +1055,7 @@ taskbar_build_gui(plugin *p)
   
     tb->gen_pixbuf =  gdk_pixbuf_new_from_xpm_data((const char **)icon_xpm);
 
-    XSelectInput (GDK_DISPLAY(), GDK_ROOT_WINDOW(), PropertyChangeMask);
+    //XSelectInput (GDK_DISPLAY(), GDK_ROOT_WINDOW(), PropertyChangeMask);
     gdk_window_add_filter(NULL, (GdkFilterFunc)tb_event_filter, tb );
 
     g_signal_connect (G_OBJECT (fbev), "current_desktop",
